@@ -3,11 +3,11 @@ from zope.component import adapts
 from zope.i18nmessageid import MessageFactory
 
 #from archetypes.markerfield.field import InterfaceMarkerField
-from Products.Archetypes.public import StringField
+from Products.Archetypes.public import StringField, BooleanField
 
 from Products.ATContentTypes.interfaces.news import IATNewsItem
-from Products.ATContentTypes.interface import IATFolder
-from Products.Archetypes.atapi import SelectionWidget
+from Products.ATContentTypes.interface import IATFolder, IATTopic
+from Products.Archetypes.atapi import SelectionWidget, BooleanWidget
 
 from archetypes.schemaextender.interfaces import ISchemaExtender, IBrowserLayerAwareExtender 
 from archetypes.schemaextender.field import ExtensionField
@@ -16,7 +16,7 @@ from medialog.newsitemview.interfaces import INewsitemObject, IFolderObject
 
 from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
 from medialog.newsitemview.vocabulary import ImageSizeVocabulary 
-
+from medialog.newsitemview.vocabulary import ImageSizesVocabulary 
 
 
 _ = MessageFactory('medialog.newsitemview')
@@ -24,7 +24,10 @@ _ = MessageFactory('medialog.newsitemview')
 
 class _StringExtensionField (ExtensionField, StringField): 
     pass
-    
+        
+class _BooleanExtensionField(ExtensionField, BooleanField):
+	pass    
+
     
 # need to get vocabulary to work from vocabulary.py    
 
@@ -37,7 +40,7 @@ class ContentTypeExtender(object):
         _StringExtensionField("newsitemsize",
             schemata = "settings",
             enforceVocabulary=True,
-            vocabulary = ImageSizeVocabulary(),
+            vocabulary = ImageSizeVocabulary,
             default="preview",
             interfaces = (INewsitemObject,),
             widget = SelectionWidget(
@@ -67,7 +70,50 @@ class FolderTypeExtender(object):
         _StringExtensionField("folderimagesize",
             schemata = "settings",
             enforceVocabulary=True,
-            vocabulary = ImageSizeVocabulary(),
+            vocabulary = ImageSizeVocabulary,
+            default="preview",
+            interfaces = (INewsitemObject,),
+            widget = SelectionWidget(
+                label = _(u"label_folderimagesize",
+                    default=u"Size for image in summary view"),
+                description = _(u"help_folderimagesize",
+                    default=u"Choose Size"),
+                ),
+            ),
+        _BooleanExtensionField("hide_images",
+            schemata = "settings",
+            interfaces = (INewsitemObject,),
+            default = False,
+            widget = BooleanWidget(
+                label = _(u"label_hide_images",
+                    default=u"Hide Images in the summary view"),
+                description = _(u"help_hide_images",
+                    default=u"Hide images from the folder view"),
+                ),
+            ),
+        ]
+
+        
+    def __init__(self, context):
+    	self.context = context
+
+    def getFields(self):
+        return self._fields
+
+#    def __init__(self, contentType):
+#        pass
+
+
+class TopicTypeExtender(object):
+    """Adapter that adds custom data used for image size."""
+    adapts(IATTopic)
+    implements(ISchemaExtender, IBrowserLayerAwareExtender)
+    layer = IFolderObject
+    _fields = [
+        _StringExtensionField("folderimagesize",
+            schemata = "settings",
+            enforceVocabulary=True,
+            vocabulary = ImageSizesVocabulary,
             default="preview",
             interfaces = (INewsitemObject,),
             widget = SelectionWidget(
